import { STSClient } from "@aws-sdk/client-sts";
import { SNSClient } from "@aws-sdk/client-sns";
import { SQSClient } from "@aws-sdk/client-sqs";
import { DocumentNode, GraphQLSchema } from "graphql";
import { EventBusPlugin, EventBusSubscriberCb, GraphQLEventbusMetadata } from "graphql-eventbus";
export type AWSEventBusConfig = {
    region: string;
    publisher?: {
        schema: GraphQLSchema;
    };
    subscriber?: {
        queries: DocumentNode;
        schema: GraphQLSchema;
        cb: EventBusSubscriberCb;
        skipTopics?: string[];
        includeTopics?: string[];
        fanoutTopics?: string[];
        /**
         * Maximum value: 20
         * Set to 0 for no wait
         */
        pollingTimeSeconds?: number;
        maxNumberOfMessages?: number;
    };
    plugins?: EventBusPlugin[];
    serviceName: string;
    isDarkRelease?: boolean;
};
export declare class AWSEventBus {
    private config;
    snsClient: SNSClient;
    sqsClient: SQSClient;
    stsClient: STSClient;
    private publishTopics;
    private closeSignal;
    private deleteSubscriptionsAndQueues;
    private ongoingPublishes;
    private existingTopicsArns;
    private bus;
    constructor(config: AWSEventBusConfig);
    private receiveMessageFromQueue;
    private pollQueue;
    private createTopic;
    private createQueue;
    closeConsumer: () => Promise<void>;
    closePublisher: () => Promise<void>;
    init: () => Promise<void>;
    publish: (a: {
        topic: string;
        payload: Record<string, unknown>;
        metadata?: Partial<GraphQLEventbusMetadata>;
        attributes?: {
            [k: string]: string;
        } | null | undefined;
    }) => Promise<void>;
}
