"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const graphql_1 = require("graphql");
const AWSEventBus_1 = require("./AWSEventBus");
const graphql_tag_1 = tslib_1.__importDefault(require("graphql-tag"));
const waait_1 = tslib_1.__importDefault(require("waait"));
jest.setTimeout(60000);
describe("AWSEventBus", () => {
    test("placeholder", () => {
        return;
    });
    if (process.env.CI === "true") {
        console.log("skipping AWSEventBus integration test in CI");
        return;
    }
    test("works", async () => {
        const schema = (0, graphql_1.buildSchema)(`
    type TestEvent {
      id: ID!
      name: String
    }
    type Query {
      TestEvent: TestEvent!
    }
  `);
        const cb = jest.fn();
        const bus = new AWSEventBus_1.AWSEventBus({
            region: "us-east-1",
            serviceName: "test",
            publisher: {
                schema,
            },
            subscriber: {
                cb: async (...args) => {
                    return cb(...args);
                },
                queries: (0, graphql_tag_1.default) `
          query TestEvent {
            TestEvent {
              id
            }
          }
        `,
                schema,
            },
        });
        await bus.init();
        cb.mockClear();
        await bus.publish({
            topic: "TestEvent",
            payload: { id: "1", name: "coolio" },
        });
        await (0, waait_1.default)(15000);
        // console.log(cb.mock.calls);
        expect(cb).toBeCalledTimes(1);
        expect(cb.mock.calls[0][0]).toMatchObject({
            _fullData: {
                id: "1",
                name: "coolio",
            },
            metadata: {},
            payload: {
                id: "1",
            },
            topic: "TestEvent",
        });
        await bus.closeConsumer();
        await bus.closePublisher();
    });
    test("dark release does not receive event without attribute", async () => {
        // if (process.env.CI !== "true") {
        //   console.log("skipping AWSEventBus test");
        //   return;
        // }
        const schema = (0, graphql_1.buildSchema)(`
    type TestEvent {
      id: ID!
      name: String
    }
    type Query {
      TestEvent: TestEvent!
    }
  `);
        const cb = jest.fn();
        const bus = new AWSEventBus_1.AWSEventBus({
            region: "us-east-1",
            serviceName: "test",
            publisher: {
                schema,
            },
            isDarkRelease: true,
            subscriber: {
                cb: async (...args) => {
                    return cb(...args);
                },
                queries: (0, graphql_tag_1.default) `
          query TestEvent {
            TestEvent {
              id
            }
          }
        `,
                schema,
            },
        });
        await bus.init();
        cb.mockClear();
        await bus.publish({
            topic: "TestEvent",
            payload: { id: "1", name: "coolio" },
        });
        await (0, waait_1.default)(15000);
        await bus.closePublisher();
        await bus.closeConsumer();
        // console.log(cb.mock.calls);
        expect(cb).not.toBeCalled();
    });
    test("dark release does receive event with dark attribute", async () => {
        // if (process.env.CI !== "true") {
        //   console.log("skipping AWSEventBus test");
        //   return;
        // }
        const schema = (0, graphql_1.buildSchema)(`
    type TestEvent {
      id: ID!
      name: String
    }
    type Query {
      TestEvent: TestEvent!
    }
  `);
        const cb = jest.fn();
        const bus = new AWSEventBus_1.AWSEventBus({
            region: "us-east-1",
            serviceName: "test",
            publisher: {
                schema,
            },
            isDarkRelease: true,
            subscriber: {
                cb: async (...args) => {
                    return cb(...args);
                },
                queries: (0, graphql_tag_1.default) `
          query TestEvent {
            TestEvent {
              id
            }
          }
        `,
                schema,
            },
        });
        await bus.init();
        cb.mockClear();
        await bus.publish({
            topic: "TestEvent",
            payload: { id: "1", name: "coolio" },
            attributes: {
                "x-prop-test-dark": "true",
            },
        });
        await (0, waait_1.default)(15000);
        // console.log(cb.mock.calls);
        expect(cb).toBeCalledTimes(1);
        expect(cb.mock.calls[0][0]).toMatchObject({
            _fullData: {
                id: "1",
                name: "coolio",
            },
            metadata: {},
            payload: {
                id: "1",
            },
            topic: "TestEvent",
        });
        await bus.closeConsumer();
        await bus.closePublisher();
    });
    test("fanout topic subscription and queue is deleted", async () => {
        // if (process.env.CI !== "true") {
        //   console.log("skipping AWSEventBus test");
        //   return;
        // }
        const schema = (0, graphql_1.buildSchema)(`
    type TestEvent {
      id: ID!
      name: String
    }
    type Query {
      TestEvent: TestEvent!
    }
  `);
        const cb = jest.fn();
        const bus = new AWSEventBus_1.AWSEventBus({
            region: "us-east-1",
            serviceName: "test",
            publisher: {
                schema,
            },
            subscriber: {
                cb: async (...args) => {
                    return cb(...args);
                },
                fanoutTopics: ["TestEvent"],
                queries: (0, graphql_tag_1.default) `
          query TestEvent {
            TestEvent {
              id
            }
          }
        `,
                schema,
            },
        });
        await bus.init();
        cb.mockClear();
        await bus.publish({
            topic: "TestEvent",
            payload: { id: "1", name: "coolio" },
        });
        await (0, waait_1.default)(15000);
        await bus.closePublisher();
        await bus.closeConsumer();
        // console.log(cb.mock.calls);
    });
});
//# sourceMappingURL=AWSEventBus.test.js.map